==> xixiBlog-0.11.zip: xixiBlog/trackback.php <==
<?php
/**
@version $Id: trackback.php,v 1.4 2004/08/20 09:50:10 minahito Exp $
*/

$xoopsOption['nocommon']=true;
include_once "../../mainfile.php";
require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";
require_once "./class/global.php";

// Form ɤ߹
include_once "exComponent/Preview.php";

// Session ɬ
require_once "./include/BlogForm.php";
include_once "./class/head.php";
include_once "./class/blog.php";

// session_start
include_once XOOPS_ROOT_PATH."/include/common.php";
include XOOPS_ROOT_PATH."/header.php";

require_once "./class/pear/PEAR.php";
require_once "./class/pear/Socket.php";
require_once "./class/pear/URL.php";
require_once "./class/pear/Request.php";


$editform=&Session::get("edit_blog");

if(!count($editform->trackbacks_)) {
	header('location: update_ping.php');
	exit;
}

$url=$editform->trackbacks_[0];

if($url) {
	if(!$editform->trackback_start_) {
    	$editform->trackback_start_=true;
    	Session::register("edit_blog",$editform);
    	redirect_header("trackback.php",1,"ȥåХåϤޤġ<br/>".$editform->trackbacks_[0]);
    	exit;
	}

	$url=array_shift($editform->trackbacks_);
   	Session::register("edit_blog",$editform);

	$dat = $editform->data_->getStructure();

	$post = &new HTTP_Request($url);
	$post->setMethod(HTTP_REQUEST_METHOD_POST);

	$post->addPostData('url',XOOPS_URL."/modules/".$xoopsModule->dirname()."/detail.php?id=".$editform->data_->getVar('id'));
	$post->addPostData('title',xoops_utf8_encode(htmlspecialchars($dat['title'])));
	$post->addPostData('blog_name',xoops_utf8_encode(htmlspecialchars($dat['blog_name'])));
	$post->addPostData('excerpt',xoops_utf8_encode(htmlspecialchars(xoops_substr(strip_tags($dat['contents']),0,255))));
	$post->addPostData('charset','utf-8');

	$post->sendRequest();
	
	if(!count($editform->trackbacks_)) {	// λ
    	header('location: update_ping.php');
	}
	else {
		redirect_header("trackback.php",1,"ȥåХåǤġ<br/>".$editform->trackbacks_[0]);
	}
}
else {
   	header('location :update_ping.php');
}

?>

==> xixiBlog-0.15.zip: xixiBlog/trackback.php <==
<?php
/**
@version $Id: trackback.php,v 1.5 2005/03/16 10:44:54 minahito Exp $
*/

$xoopsOption['nocommon']=true;
include_once "../../mainfile.php";
require_once XOOPS_ROOT_PATH."/modules/exFrame/frameloader.php";
require_once "./class/global.php";

// Form ɤ߹
include_once "exComponent/Preview.php";

// Session ɬ
require_once "./include/BlogForm.php";
include_once "./class/head.php";
include_once "./class/blog.php";

// session_start
include_once XOOPS_ROOT_PATH."/include/common.php";
include XOOPS_ROOT_PATH."/header.php";

require_once "./class/trackback_send.php";

$editform=&Session::get("edit_blog");

if(!count($editform->trackbacks_)) {
	header('location: update_ping.php');
	exit;
}

$url=$editform->trackbacks_[0];

if($url) {
	if(!$editform->trackback_start_) {
    	$editform->trackback_start_=true;
    	Session::register("edit_blog",$editform);
    	redirect_header("trackback.php",1,"ȥåХåϤޤġ<br/>".$editform->trackbacks_[0]);
    	exit;
	}

	$url=array_shift($editform->trackbacks_);
   	Session::register("edit_blog",$editform);

	$dat = $editform->data_->getStructure();

	$post = new TrackbackSendObject (
				XOOPS_URL."/modules/".$xoopsModule->dirname()."/detail.php?id=".$editform->data_->getVar('id'),
				$dat['title'],
				$dat['blog_name'],
				$dat['contents']
			);
	$post->send($url);
	
	if(!count($editform->trackbacks_)) {	// λ
    	header('location: update_ping.php');
	}
	else {
		redirect_header("trackback.php",1,"ȥåХåǤġ<br/>".$editform->trackbacks_[0]);
	}
}
else {
   	header('location :update_ping.php');
}

?>
